==> akonadi-25.04.0.tgz: lib/cmake/KPim6Akonadi/KPim6AkonadiTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPim6::AkonadiPrivate" for configuration "Release"
set_property(TARGET KPim6::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiPrivate.so.1.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiPrivate.so.1.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiPrivate )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKPim6AkonadiPrivate.so.1.0" )

# Import target "KPim6::AkonadiCore" for configuration "Release"
set_property(TARGET KPim6::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Network;Qt6::Widgets;KF6::I18n;KF6::IconThemes;KF6::ConfigCore;KPim6::AkonadiPrivate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiCore.so.1.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiCore.so.1.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiCore )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiCore "${_IMPORT_PREFIX}/lib/libKPim6AkonadiCore.so.1.0" )

# Import target "KPim6::AkonadiAgentBase" for configuration "Release"
set_property(TARGET KPim6::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KPim6::AkonadiPrivate;KPim6::AkonadiWidgets;KF6::I18n;Qt6::Network;KF6::IconThemes;KAccounts6;Qt6::Xml"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentBase.so.1.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiAgentBase.so.1.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiAgentBase )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentBase.so.1.0" )

# Import target "KPim6::AkonadiWidgets" for configuration "Release"
set_property(TARGET KPim6::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n;KF6::IconThemes;KF6::IconWidgets;KF6::XmlGui;Qt6::Sql;KPim6::AkonadiPrivate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiWidgets.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiWidgets.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiWidgets )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKPim6AkonadiWidgets.so.0.0" )

# Import target "KPim6::AkonadiXml" for configuration "Release"
set_property(TARGET KPim6::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiXml.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiXml.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiXml )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiXml "${_IMPORT_PREFIX}/lib/libKPim6AkonadiXml.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> akonadi-25.08.1.tgz: lib/cmake/KPim6Akonadi/KPim6AkonadiTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KPim6::AkonadiPrivate" for configuration "Release"
set_property(TARGET KPim6::AkonadiPrivate APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiPrivate PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiPrivate.so.1.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiPrivate.so.1.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiPrivate )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiPrivate "${_IMPORT_PREFIX}/lib/libKPim6AkonadiPrivate.so.1.0" )

# Import target "KPim6::AkonadiCore" for configuration "Release"
set_property(TARGET KPim6::AkonadiCore APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiCore PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "Qt6::Network;KF6::I18n;KF6::IconThemes;KF6::ConfigCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiCore.so.2.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiCore.so.2.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiCore )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiCore "${_IMPORT_PREFIX}/lib/libKPim6AkonadiCore.so.2.0" )

# Import target "KPim6::AkonadiAgentBase" for configuration "Release"
set_property(TARGET KPim6::AkonadiAgentBase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiAgentBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KPim6::AkonadiPrivate;KF6::I18n;Qt6::Network;KAccounts6;Qt6::Xml"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentBase.so.1.1"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiAgentBase.so.1.1"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiAgentBase )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiAgentBase "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentBase.so.1.1" )

# Import target "KPim6::AkonadiAgentWidgetBase" for configuration "Release"
set_property(TARGET KPim6::AkonadiAgentWidgetBase APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiAgentWidgetBase PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KPim6::AkonadiWidgets;KF6::IconThemes"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentWidgetBase.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiAgentWidgetBase.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiAgentWidgetBase )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiAgentWidgetBase "${_IMPORT_PREFIX}/lib/libKPim6AkonadiAgentWidgetBase.so.0.0" )

# Import target "KPim6::AkonadiWidgets" for configuration "Release"
set_property(TARGET KPim6::AkonadiWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n;KF6::IconThemes;KF6::IconWidgets;KF6::XmlGui;KF6::ColorScheme;Qt6::Sql;KPim6::AkonadiPrivate"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiWidgets.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiWidgets.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiWidgets )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiWidgets "${_IMPORT_PREFIX}/lib/libKPim6AkonadiWidgets.so.0.0" )

# Import target "KPim6::AkonadiXml" for configuration "Release"
set_property(TARGET KPim6::AkonadiXml APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KPim6::AkonadiXml PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF6::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKPim6AkonadiXml.so.0.0"
  IMPORTED_SONAME_RELEASE "libKPim6AkonadiXml.so.0.0"
  )

list(APPEND _cmake_import_check_targets KPim6::AkonadiXml )
list(APPEND _cmake_import_check_files_for_KPim6::AkonadiXml "${_IMPORT_PREFIX}/lib/libKPim6AkonadiXml.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
